function [pt p dp p2 dp2 p3 dp3 txc xc]=getdata(path)
%calling sequence:
%       [pt p dp p2 dp2 p3 dp3 txc xc]=getdata(path)
% Returns the data loaded from the files pend.ASC and carriage.ASC in the
% directory given in path.
%
% 	pt: time instances, [sec].
%
% 	p: angle at the corresponding time instances, [degrees].
%
% 	dp: first order derivative (forward difference), [degrees/sec].
%
% 	p2: index rearrangement in p.  When combined with dp2, provides a
% 	second order approximation of the derivative for phase diagrams,
% 	[degrees].
%
% 	dp2: second order derivative (centered difference), [degrees/sec].
%
% 	p3: angle at intermediate time instances.  When used with dp3 (same as
% 	dp), provides a second order approximation of the derivative for phase
% 	diagrams, [degrees].
%
% 	dp3: same as dp, [degrees/sec].

p=load([path 'pend.ASC']);

dt=p(2,1)-p(1,1);

pt=p(1:end-1,1);
dp=diff(p(:,2))/dt;

%second order quantities. They don't have temporal shift dt/2

%Centered escheme at t_{n}
dp2=-(p(1:(end-2),2)-p(3:end,2))/dt/2;
p2=p(2:(end-1),2);

%Centered escheme at t_{n+1/2}
dp3=diff(p(:,2))/dt;
p3=(p(1:(end-1),2)+p(2:end,2))/2;

p=p(1:end-1,2);

xc=load([path 'carriage.ASC']);

txc=xc(:,1);
xc=xc(:,2);